@@ -1,6 +1,8 @@
 /* These stubs are provided so that autoconf can check library
  * versions using C symbols only */
 
+extern void libvamphostsdk_v_2_7_1_present(void) { }
+extern void libvamphostsdk_v_2_7_present(void) { }
 extern void libvamphostsdk_v_2_6_present(void) { }
 extern void libvamphostsdk_v_2_5_present(void) { }
 extern void libvamphostsdk_v_2_4_present(void) { }
